@@ -17,6 +17,9 @@
 
 #include "bookmarksmodel.h"
 #include "cache.h"
+#include "launcher.h"
+#include "searchenginemodel.h"
+#include "settings.h"
 #include <QApplication>
 #include <QDeclarativeEngine>
 #include <QDeclarativeContext>
@@ -28,18 +31,32 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
     app.setOrganizationName("QMLBrowser");
-    app.setApplicationName("Browser");
+    app.setApplicationName("QML Browser");
 
     qmlRegisterUncreatableType<BookmarksModel>("org.hildon.browser", 1, 0, "BookmarksModel", "");
+    qmlRegisterUncreatableType<SearchEngineModel>("org.hildon.browser", 1, 0, "SearchEngineModel", "");
 
     Cache cache;
     cache.create();
 
+    Launcher launcher;
+    launcher.loadHandlers();
+
+    Settings settings;
+
     BookmarksModel bookmarks;
     bookmarks.setFileName("/home/user/.config/QMLBrowser/bookmarks.xml");
+    bookmarks.load();
+
+    SearchEngineModel searchEngines;
+    searchEngines.setFileName("/home/user/.config/QMLBrowser/searchengines.conf");
+    searchEngines.load();
 
     QDeclarativeEngine engine;
+    engine.rootContext()->setContextProperty("launcher", &launcher);
     engine.rootContext()->setContextProperty("bookmarks", &bookmarks);
+    engine.rootContext()->setContextProperty("searchEngines", &searchEngines);
+    engine.rootContext()->setContextProperty("qmlBrowserSettings", &settings);
 
     QDeclarativeComponent component(&engine, QUrl("qrc:/main.qml"));
     component.create();
